@@ -77,35 +77,37 @@ class ChessDaskCluster:
             raise FileNotFoundError(
                 errno.ENOENT, os.strerror(errno.ENOENT), config_file)
         with open(config_file) as file:
-            config_values = yaml.full_load(file)
-        if config_values["cluster_name"] is None:
-            config_values["cluster_name"] = "chess-cluster"
-        if config_values["software_environment_name"] is None:
-            config_values["software_environment_name"] = "chess-env"
-        if config_values["n_workers"] is None:
-            config_values["n_workers"] = 8
-        if config_values["worker_cpu"] is None:
-            config_values["worker_cpu"] = 4
-        if config_values["worker_memory"] is None:
-            config_values["worker_memory"] = 16
-        if config_values["scheduler_memory"] is None:
-            config_values["scheduler_memory"] = 16
-        if config_values["scheduler_cpu"] is None:
-            config_values["scheduler_cpu"] = 4
+            self.config_values = yaml.full_load(file)
+        if self.config_values["cluster_name"] is None:
+            self.config_values["cluster_name"] = "chess-cluster"
+        if self.config_values["software_environment_name"] is None:
+            self.config_values["software_environment_name"] = "chess-env"
+        if self.config_values["n_workers"] is None:
+            self.config_values["n_workers"] = 8
+        if self.config_values["worker_cpu"] is None:
+            self.config_values["worker_cpu"] = 4
+        if self.config_values["worker_memory"] is None:
+            self.config_values["worker_memory"] = 16
+        if self.config_values["scheduler_memory"] is None:
+            self.config_values["scheduler_memory"] = 16
+        if self.config_values["scheduler_cpu"] is None:
+            self.config_values["scheduler_cpu"] = 4
+        if self.config_values["game_batch_size"] is None:
+            self.config_values["game_batch_size"] = 50
 
-        if config_values["use_local_cluster"]:
-            cluster = LocalCluster(n_workers=config_values["n_workers"],
+        if self.config_values["use_local_cluster"]:
+            cluster = LocalCluster(n_workers=self.config_values["n_workers"],
                                     threads_per_worker=1)
         else:
-            coiled.create_software_environment(name=config_values["software_environment_name"],
+            coiled.create_software_environment(name=self.config_values["software_environment_name"],
                                                 pip="requirements.txt")
-            cluster = coiled.Cluster(name=config_values["cluster_name"],
-                                    n_workers=config_values["n_workers"],
-                                    worker_cpu=config_values["worker_cpu"],
-                                    worker_memory=str(config_values["worker_memory"]) +"GiB",
-                                    scheduler_memory=str(config_values["scheduler_memory"]) +"GiB",
-                                    scheduler_cpu=config_values["scheduler_cpu"],
-                                    software=config_values["software_environment_name"])
+            cluster = coiled.Cluster(name=self.config_values["cluster_name"],
+                                    n_workers=self.config_values["n_workers"],
+                                    worker_cpu=self.config_values["worker_cpu"],
+                                    worker_memory=str(self.config_values["worker_memory"]) +"GiB",
+                                    scheduler_memory=str(self.config_values["scheduler_memory"]) +"GiB",
+                                    scheduler_cpu=self.config_values["scheduler_cpu"],
+                                    software=self.config_values["software_environment_name"])
 
         self.client = Client(cluster)
 
@@ -113,12 +115,15 @@ class ChessDaskCluster:
         "Find control heatmap for all the games passed in parallel in a dask cluster"
         game_no = 0
         game_futures = []
+        results = []
         for game in game_list:
             game_futures.append(self.client.submit(ChessDaskCluster.run_in_parallel,
                                  *(game, game_no)))
             game_no = game_no + 1
-        wait(game_futures)
-        results = []
-        for future in game_futures:
-            results.append(future.result())
+            if game_no % self.config_values["game_batch_size"] == 0:
+                results.extend(self.client.gather(game_futures))
+                game_futures = []
+                print("Completed till " + str(game_no))
+        results.extend(self.client.gather(game_futures))
+        print("Completed all")
         return results
